@@ -2,7 +2,7 @@
 
 from __future__ import print_function, division
 
-from sympy.core import Symbol, Dummy
+from sympy.core import Symbol, Dummy, sympify
 from sympy.core.compatibility import iterable, reduce
 from sympy.sets import Interval
 from sympy.core.relational import Relational, Eq, Ge, Lt
@@ -215,7 +215,7 @@ def reduce_rational_inequalities(exprs, gen, relational=True):
     """
     exact = True
     eqs = []
-    solution = S.EmptySet
+    solution = S.Reals if exprs else S.EmptySet
     for _exprs in exprs:
         _eqs = []
 
@@ -251,13 +251,15 @@ def reduce_rational_inequalities(exprs, gen, relational=True):
             if not (domain.is_ZZ or domain.is_QQ):
                 expr = numer/denom
                 expr = Relational(expr, 0, rel)
-                solution = Union(solution, solve_univariate_inequality(expr, gen, relational=False))
+                solution &= solve_univariate_inequality(expr, gen, relational=False)
             else:
                 _eqs.append(((numer, denom), rel))
 
-        eqs.append(_eqs)
+        if _eqs:
+            eqs.append(_eqs)
 
-    solution = Union(solution, solve_rational_inequalities(eqs))
+    if eqs:
+        solution &= solve_rational_inequalities(eqs)
 
     if not exact:
         solution = solution.evalf()
@@ -454,7 +456,11 @@ def solve_univariate_inequality(expr, gen, relational=True):
                     sol_sets.append(Interval(start, S.Infinity, True, True))
                     break
 
-            if valid((start + end)/2 if start != S.NegativeInfinity else end - 1):
+            pt = ((start + end)/2 if start is not S.NegativeInfinity else
+                (end/2 if end.is_positive else
+                (2*end if end.is_negative else
+                end - 1)))
+            if valid(pt):
                 sol_sets.append(Interval(start, end, True, True))
 
             if x in singularities:
@@ -466,7 +472,15 @@ def solve_univariate_inequality(expr, gen, relational=True):
 
         end = S.Infinity
 
-        if valid(start + 1):
+        # in case start == -oo then there were no solutions so we just
+        # check a point between -oo and oo (e.g. 0) else pick a point
+        # past the last solution (which is start after the end of the
+        # for-loop above
+        pt = (0 if start is S.NegativeInfinity else
+            (start/2 if start.is_negative else
+            (2*start if start.is_positive else
+            start + 1)))
+        if valid(pt):
             sol_sets.append(Interval(start, end, True, True))
 
         rv = Union(*sol_sets).subs(gen, _gen)
@@ -477,8 +491,6 @@ def solve_univariate_inequality(expr, gen, relational=True):
 def _solve_inequality(ie, s):
     """ A hacky replacement for solve, since the latter only works for
         univariate inequalities. """
-    if not ie.rel_op in ('>', '>=', '<', '<='):
-        raise NotImplementedError
     expr = ie.lhs - ie.rhs
     try:
         p = Poly(expr, s)
@@ -486,15 +498,14 @@ def _solve_inequality(ie, s):
             raise NotImplementedError
     except (PolynomialError, NotImplementedError):
         try:
-            n, d = expr.as_numer_denom()
             return reduce_rational_inequalities([[ie]], s)
         except PolynomialError:
             return solve_univariate_inequality(ie, s)
     a, b = p.all_coeffs()
-    if a.is_positive:
+    if a.is_positive or ie.rel_op in ('!=', '=='):
         return ie.func(s, -b/a)
     elif a.is_negative:
-        return ie.func(-b/a, s)
+        return ie.reversed.func(s, -b/a)
     else:
         raise NotImplementedError
 
@@ -568,6 +579,22 @@ def reduce_inequalities(inequalities, symbols=[]):
     """
     if not iterable(inequalities):
         inequalities = [inequalities]
+    inequalities = [sympify(i) for i in inequalities]
+
+    gens = set().union(*[i.free_symbols for i in inequalities])
+
+    if not iterable(symbols):
+        symbols = [symbols]
+    symbols = (set(symbols) or gens) & gens
+    if any(i.is_real is False for i in symbols):
+        raise TypeError(filldedent('''
+            inequalities cannot contain symbols that are not real.'''))
+
+    # make vanilla symbol real
+    recast = dict([(i, Dummy(i.name, real=True))
+        for i in gens if i.is_real is None])
+    inequalities = [i.xreplace(recast) for i in inequalities]
+    symbols = set([i.xreplace(recast) for i in symbols])
 
     # prefilter
     keep = []
@@ -587,18 +614,6 @@ def reduce_inequalities(inequalities, symbols=[]):
     inequalities = keep
     del keep
 
-    gens = reduce(set.union, [i.free_symbols for i in inequalities], set())
-
-    if not iterable(symbols):
-        symbols = [symbols]
-    symbols = set(symbols) or gens
-
-    # make vanilla symbol real
-    recast = dict([(i, Dummy(i.name, real=True))
-        for i in gens if i.is_real is None])
-    inequalities = [i.xreplace(recast) for i in inequalities]
-    symbols = set([i.xreplace(recast) for i in symbols])
-
     # solve system
     rv = _reduce_inequalities(inequalities, symbols)
 
